/****************************************************************************
** $Id: quickinterpreterinterfaceimpl.cpp  beta3   edited Mar 5 11:23 $
**
** Copyright (C) 2001-2002 Trolltech AS.  All rights reserved.
**
** This file is part of the Qt Script for Applications framework (QSA).
**
** This file may be distributed and/or modified under the terms of the
** GNU General Public License version 2 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.
**
** Licensees holding a valid QSA Beta Evaluation Version license may use
** this file in accordance with the QSA Beta Evaluation Version License
** Agreement provided with the Software.
**
** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
**
** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
**   information about QSA Commercial License Agreements.
** See http://www.trolltech.com/gpl/ for GPL licensing information.
**
** Contact info@trolltech.com if any conditions of this licensing are
** not clear to you.
**
*****************************************************************************/

#include "quickinterpreterinterfaceimpl.h"
#include "quickinterpreter.h"
#include "quickdebugger.h"
#include "../qsa/qsproject.h"
#include <qapplication.h>

QuickInterpreterInterfaceImpl::QuickInterpreterInterfaceImpl()
    : ref( 0 )
{
}

QuickInterpreterInterfaceImpl::~QuickInterpreterInterfaceImpl()
{
}

QRESULT QuickInterpreterInterfaceImpl::queryInterface( const QUuid &uuid,
						       QUnknownInterface **iface )
{
    *iface = 0;
    if ( uuid == IID_QUnknown )
	*iface = (QUnknownInterface*)this;
    else if ( uuid == IID_Interpreter )
	*iface = (InterpreterInterface*)this;
    else
	return QE_NOINTERFACE;

    (*iface)->addRef();
    return QS_OK;
}

unsigned long QuickInterpreterInterfaceImpl::addRef()
{
    return ref++;
}

unsigned long QuickInterpreterInterfaceImpl::release()
{
    if ( !--ref ) {
	delete this;
	return 0;
    }
    return ref;
}

void QuickInterpreterInterfaceImpl::setBreakPoints( QObject *obj,
						    const QValueList<uint> &lst )
{
    QuickInterpreter *ip = QSProject::ideQuickInterpreter();
    int sourceId = ip->sourceIdOfObject( obj );
    Q_ASSERT( sourceId>=0 );
    if( sourceId<0 ) {
	return;
    }
    ip->debuggerEngine()->clearAllBreakpoints( sourceId );
    for ( QValueList<uint>::ConstIterator bit = lst.begin(); bit != lst.end(); ++bit )
	ip->debuggerEngine()->setBreakpoint( sourceId, *bit );
}
